@@ -1,28 +1,13 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-
 #include "kiokdeconnect.h"
 
-#include <QThread>
 #include <QDBusMetaType>
+#include <QThread>
 
 #include <KLocalizedString>
 
@@ -37,7 +22,7 @@ class KIOPluginForMetaData : public QObject
     Q_PLUGIN_METADATA(IID "org.kde.kio.slave.kdeconnect" FILE "kdeconnect.json")
 };
 
-extern "C" int Q_DECL_EXPORT kdemain(int argc, char** argv)
+extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kio_kdeconnect"));
@@ -47,60 +32,56 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char** argv)
         exit(-1);
     }
 
-    KioKdeconnect slave(argv[2], argv[3]);
-    slave.dispatchLoop();
+    KioKdeconnect worker(argv[2], argv[3]);
+    worker.dispatchLoop();
     return 0;
 }
 
-//Some useful error mapping
+// Some useful error mapping
 KIO::Error toKioError(const QDBusError::ErrorType type)
 {
-    switch (type)
-    {
-        case QDBusError::NoError:
-            return KIO::Error(KJob::NoError);
-        case QDBusError::NoMemory:
-            return KIO::ERR_OUT_OF_MEMORY;
-        case QDBusError::Timeout:
-            return KIO::ERR_SERVER_TIMEOUT;
-        case QDBusError::TimedOut:
-            return KIO::ERR_SERVER_TIMEOUT;
-        default:
-            return KIO::ERR_SLAVE_DEFINED;
+    switch (type) {
+    case QDBusError::NoError:
+        return KIO::Error(KJob::NoError);
+    case QDBusError::NoMemory:
+        return KIO::ERR_OUT_OF_MEMORY;
+    case QDBusError::Timeout:
+        return KIO::ERR_SERVER_TIMEOUT;
+    case QDBusError::TimedOut:
+        return KIO::ERR_SERVER_TIMEOUT;
+    default:
+        return KIO::ERR_WORKER_DEFINED;
     };
 };
 
-template <typename T>
-bool handleDBusError(QDBusReply<T>& reply, KIO::SlaveBase* slave)
+template<typename T>
+KIO::WorkerResult handleDBusError(QDBusReply<T> &reply)
 {
-    if (!reply.isValid())
-    {
+    if (!reply.isValid()) {
         qCDebug(KDECONNECT_KIO) << "Error in DBus request:" << reply.error();
-        slave->error(toKioError(reply.error().type()),reply.error().message());
-        return true;
+        return KIO::WorkerResult::fail(toKioError(reply.error().type()), reply.error().message());
     }
-    return false;
+    return KIO::WorkerResult::pass();
 }
 
-KioKdeconnect::KioKdeconnect(const QByteArray& pool, const QByteArray& app)
-    : SlaveBase("kdeconnect", pool, app),
-    m_dbusInterface(new DaemonDbusInterface(this))
+KioKdeconnect::KioKdeconnect(const QByteArray &pool, const QByteArray &app)
+    : WorkerBase("kdeconnect", pool, app)
+    , m_dbusInterface(new DaemonDbusInterface(this))
 {
-
 }
 
-void KioKdeconnect::listAllDevices()
+KIO::WorkerResult KioKdeconnect::listAllDevices()
 {
     infoMessage(i18n("Listing devices..."));
 
-    //TODO: Change to all devices and show different icons for connected and disconnected?
+    // TODO: Change to all devices and show different icons for connected and disconnected?
     const QStringList devices = m_dbusInterface->devices(true, true);
 
-    for (const QString& deviceId : devices) {
-
+    for (const QString &deviceId : devices) {
         DeviceDbusInterface interface(deviceId);
 
-        if (!interface.hasPlugin(QStringLiteral("kdeconnect_sftp"))) continue;
+        if (!interface.hasPlugin(QStringLiteral("kdeconnect_sftp")))
+            continue;
 
         const QString path = QStringLiteral("kdeconnect://").append(deviceId).append(QStringLiteral("/"));
         const QString name = interface.name();
@@ -111,9 +92,9 @@ void KioKdeconnect::listAllDevices()
         entry.fastInsert(KIO::UDSEntry::UDS_NAME, name);
         entry.fastInsert(KIO::UDSEntry::UDS_ICON_NAME, icon);
         entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
-        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::ExeOwner
-                                                | QFileDevice::ReadGroup | QFileDevice::ExeGroup
-                                                | QFileDevice::ReadOther | QFileDevice::ExeOther);
+        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
+                         QFileDevice::ReadOwner | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::ExeGroup | QFileDevice::ReadOther
+                             | QFileDevice::ExeOther);
         entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
         entry.fastInsert(KIO::UDSEntry::UDS_URL, path);
         listEntry(entry);
@@ -125,16 +106,16 @@ void KioKdeconnect::listAllDevices()
     entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
     entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
     entry.fastInsert(KIO::UDSEntry::UDS_SIZE, 0);
-    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::WriteOwner
-                    | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::WriteGroup
-                    | QFileDevice::ExeGroup | QFileDevice::ReadOther | QFileDevice::ExeOther);
+    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
+                     QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::WriteGroup
+                         | QFileDevice::ExeGroup | QFileDevice::ReadOther | QFileDevice::ExeOther);
     listEntry(entry);
 
     infoMessage(QLatin1String(""));
-    finished();
+    return KIO::WorkerResult::pass();
 }
 
-void KioKdeconnect::listDevice(const QString& device)
+KIO::WorkerResult KioKdeconnect::listDevice(const QString &device)
 {
     infoMessage(i18n("Accessing device..."));
 
@@ -145,54 +126,47 @@ void KioKdeconnect::listDevice(const QString& device)
     QDBusReply<bool> mountreply = interface.mountAndWait();
 
     if (mountreply.error().type() == QDBusError::UnknownObject) {
-
         DaemonDbusInterface daemon;
 
         auto devsRepl = daemon.devices(false, false);
         devsRepl.waitForFinished();
 
         if (!devsRepl.value().contains(device)) {
-            error(KIO::ERR_SLAVE_DEFINED, i18n("No such device: %0").arg(device));
-            return;
+            return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("No such device: %0").arg(device));
         }
 
         DeviceDbusInterface dev(device);
 
-        if (!dev.isTrusted()) {
-            error(KIO::ERR_SLAVE_DEFINED, i18n("%0 is not paired").arg(dev.name()));
-            return;
+        if (!dev.isPaired()) {
+            return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("%0 is not paired").arg(dev.name()));
         }
 
         if (!dev.isReachable()) {
-            error(KIO::ERR_SLAVE_DEFINED, i18n("%0 is not connected").arg(dev.name()));
-            return;
+            return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("%0 is not connected").arg(dev.name()));
         }
 
         if (!dev.hasPlugin(QStringLiteral("kdeconnect_sftp"))) {
-            error(KIO::ERR_SLAVE_DEFINED, i18n("%0 has no Remote Filesystem plugin").arg(dev.name()));
-            return;
+            return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("%0 has no Remote Filesystem plugin").arg(dev.name()));
         }
     }
 
-    if (handleDBusError(mountreply, this)) {
-        return;
+    if (auto result = handleDBusError(mountreply); !result.success()) {
+        return result;
     }
 
     if (!mountreply.value()) {
-        error(KIO::ERR_SLAVE_DEFINED, interface.getMountError());
-        return;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, interface.getMountError());
     }
 
-    QDBusReply< QVariantMap > urlreply = interface.getDirectories();
+    QDBusReply<QVariantMap> urlreply = interface.getDirectories();
 
-    if (handleDBusError(urlreply, this)) {
-        return;
+    if (auto result = handleDBusError(urlreply); !result.success()) {
+        return result;
     }
 
     QVariantMap urls = urlreply.value();
 
     for (QVariantMap::iterator it = urls.begin(); it != urls.end(); ++it) {
-
         const QString path = it.key();
         const QString name = it.value().toString();
         const QString icon = QStringLiteral("folder");
@@ -202,9 +176,9 @@ void KioKdeconnect::listDevice(const QString& device)
         entry.fastInsert(KIO::UDSEntry::UDS_NAME, name);
         entry.fastInsert(KIO::UDSEntry::UDS_ICON_NAME, icon);
         entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
-        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::ExeOwner
-                                                | QFileDevice::ReadGroup | QFileDevice::ExeGroup
-                                                | QFileDevice::ReadOther | QFileDevice::ExeOther);
+        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
+                         QFileDevice::ReadOwner | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::ExeGroup | QFileDevice::ReadOther
+                             | QFileDevice::ExeOther);
         entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
         entry.fastInsert(KIO::UDSEntry::UDS_URL, QUrl::fromLocalFile(path).toString());
         listEntry(entry);
@@ -216,39 +190,34 @@ void KioKdeconnect::listDevice(const QString& device)
     entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
     entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
     entry.fastInsert(KIO::UDSEntry::UDS_SIZE, 0);
-    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::WriteOwner
-                    | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::WriteGroup
-                    | QFileDevice::ExeGroup | QFileDevice::ReadOther | QFileDevice::ExeOther);
+    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
+                     QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::WriteGroup
+                         | QFileDevice::ExeGroup | QFileDevice::ReadOther | QFileDevice::ExeOther);
 
     listEntry(entry);
 
     infoMessage(QLatin1String(""));
-    finished();
-
+    return KIO::WorkerResult::pass();
 }
 
-
-
-void KioKdeconnect::listDir(const QUrl& url)
+KIO::WorkerResult KioKdeconnect::listDir(const QUrl &url)
 {
     qCDebug(KDECONNECT_KIO) << "Listing..." << url;
 
     if (!m_dbusInterface->isValid()) {
-        infoMessage(i18n("Could not contact background service."));
-        finished();
-        return;
+        return KIO::WorkerResult::fail(KIO::Error::ERR_WORKER_DEFINED, i18n("Could not contact background service."));
     }
 
     QString currentDevice = url.host();
 
     if (currentDevice.isEmpty()) {
-        listAllDevices();
+        return listAllDevices();
     } else {
-        listDevice(currentDevice);
+        return listDevice(currentDevice);
     }
 }
 
-void KioKdeconnect::stat(const QUrl& url)
+KIO::WorkerResult KioKdeconnect::stat(const QUrl &url)
 {
     qCDebug(KDECONNECT_KIO) << "Stat: " << url;
 
@@ -270,15 +239,15 @@ void KioKdeconnect::stat(const QUrl& url)
 
     statEntry(entry);
 
-    finished();
+    return KIO::WorkerResult::pass();
 }
 
-void KioKdeconnect::get(const QUrl& url)
+KIO::WorkerResult KioKdeconnect::get(const QUrl &url)
 {
     qCDebug(KDECONNECT_KIO) << "Get: " << url;
     mimeType(QLatin1String(""));
-    finished();
+    return KIO::WorkerResult::pass();
 }
 
-//needed for JSON file embedding
 #include "kiokdeconnect.moc"
+#include "moc_kiokdeconnect.cpp"
